@@ -2331,8 +2331,8 @@ enum
 };
 
 /* Define CC and CFLAGS which were used to build this version of GMP */
-#define __GMP_CC "armv7a-softfp-linux-gnueabi-gcc"
-#define __GMP_CFLAGS "-O2 -pipe -march=armv7-a -mfpu=vfpv3-d16 -mfloat-abi=softfp"
+#define __GMP_CC "armv6j-unknown-linux-musleabihf-gcc"
+#define __GMP_CFLAGS "-O2 -pipe -march=armv6j -mfpu=vfp -mfloat-abi=hard"
 
 /* Major version number is the value of __GNU_MP__ too, above. */
 #define __GNU_MP_VERSION            6
